# AI Training utils

This package contains utils which can be used while training AI models:
- Path Helper: Makes use of argparse to obtain the right directories for the dataset, output artifacts and logging output.
- Logging Helper: Logger with file handler which writes the logging output to the given path in the arguments.
- Singleton: Helper class to make it possible to use classes as Singleton
